==> nextcloud-12.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/files_sharing/l10n/es_MX.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Shared with you" : "Compartido contigo",
    "Shared with others" : "Compartido con otros",
    "Shared by link" : "Compartido por liga",
    "Nothing shared with you yet" : "Nada ha sido compartido contigo aún",
    "Files and folders others share with you will show up here" : "Los archivos y carpetas que sean compartidos contigo se mostrarán aquí",
    "Nothing shared yet" : "Nada compartido aún",
    "Files and folders you share will show up here" : "Los archivos y carpetas que compartas se mostrarán aquí",
    "No shared links" : "No hay ligas compartidas",
    "Files and folders you share by link will show up here" : "Los archivos y carpetas que compartas por ligas se mostrarán aquí",
    "You can upload into this folder" : "Puedes cargar archivos dentro de esta carpeta",
    "No compatible server found at {remote}" : "No se encontró un servidor compatible en {remote}",
    "Invalid server URL" : "URL del servidor inválido",
    "Failed to add the public link to your Nextcloud" : "Se presentó una falla al agregar la liga pública a tu Nextcloud",
    "Share" : "Compartir",
    "No expiration date set" : "No se ha establecido la fecha de expiración",
    "Shared by" : "Compartido por",
    "Sharing" : "Compartiendo",
    "File shares" : "Archivos compartidos",
    "Downloaded via public link" : "Descargado mediante una liga pública",
    "Downloaded by {email}" : "Descargado por {email}",
    "{file} downloaded via public link" : "{file} descargado mediante una liga pública",
    "{email} downloaded {file}" : "{email} descargó {file}",
    "Shared with group {group}" : "Compartido con el gupo {group}",
    "Removed share for group {group}" : "Se eliminó el elemento compartido del grupo {group}",
    "{actor} shared with group {group}" : "{actor} compartió con el grupo {group}",
    "{actor} removed share for group {group}" : "{actor} eliminó el elemento compartido del grupo {group}",
    "You shared {file} with group {group}" : "Compartiste {file} con el grupo {group}",
    "You removed group {group} from {file}" : "Eliminaste al grupo {group} de {file}",
    "{actor} shared {file} with group {group}" : "{actor} compartió {file} con el grupo {group}",
    "{actor} removed group {group} from {file}" : "{actor} eliminó el grupo {group} de {file}",
    "Shared as public link" : "Compartido como una liga pública",
    "Removed public link" : "Liga pública eliminada",
    "Public link expired" : "La liga pública ha expirado",
    "{actor} shared as public link" : "{actor} compartió como una liga pública",
    "{actor} removed public link" : "{actor} eliminó la liga pública",
    "Public link of {actor} expired" : "La liga pública de {actor} ha expirado",
    "You shared {file} as public link" : "Compartiste {file} como una liga pública",
    "You removed public link for {file}" : "Eliminaste la liga pública de {file}",
    "Public link expired for {file}" : "La liga pública para {file} ha expirado",
    "{actor} shared {file} as public link" : "{actor} ha compartido {file} como una liga pública",
    "{actor} removed public link for {file}" : "{actor} eliminó la liga pública de {file}",
    "Public link of {actor} for {file} expired" : "La liga pública de {actor} para {file} ha expirado",
    "{user} accepted the remote share" : "{user} aceptó el elemento compartido remoto",
    "{user} declined the remote share" : "{user} declinó el elemento compartido remoto",
    "You received a new remote share {file} from {user}" : "Recibiste un nuevo elemento compartido remoto {file} de {user}",
    "{user} accepted the remote share of {file}" : "{user} aceptó el elemento compartido remoto de {file}",
    "{user} declined the remote share of {file}" : "{user} declinó el elemento compartido remoto de {file}",
    "{user} unshared {file} from you" : "{user} ha dejado de compartir {file} contigo",
    "Shared with {user}" : "Compartido con {user}",
    "Removed share for {user}" : "Se eliminó el elemento compartido para {user}",
    "{actor} shared with {user}" : "{actor} compartió con {user}",
    "{actor} removed share for {user}" : "{actor} eliminó el elemento compartido para {user}",
    "Shared by {actor}" : "Compartido por {actor}",
    "{actor} removed share" : "{actor} eliminó el elemento compartido",
    "You shared {file} with {user}" : "Compartiste {file} con {user}",
    "You removed {user} from {file}" : "Eliminaste a {user} de {file}",
    "{actor} shared {file} with {user}" : "{actor} compartió {file} con {user}",
    "{actor} removed {user} from {file}" : "{actor} eliminó a {user} de {file}",
    "{actor} shared {file} with you" : "{actor} ha compartido {file} contigo",
    "{actor} removed you from {file}" : "{actor} lo eliminó de {file}",
    "A file or folder shared by mail or by public link was <strong>downloaded</strong>" : "Un archivo o carpeta comparitdo por correo o por liga pública ha sido <strong>descargado</strong>",
    "A file or folder was shared from <strong>another server</strong>" : "Un archivo o carpeta fue compartido desde <strong>otro servidor</strong>",
    "A file or folder has been <strong>shared</strong>" : "Un archivo o carpeta ha sido <strong>compartido</strong>",
    "Wrong share ID, share doesn't exist" : "ID del elemento compartido equivocado, el elemento compartido no existe",
    "could not delete share" : "no fue posible borrar el elemento compartido",
    "Could not delete share" : "No fue posible borrar el elemento compartido",
    "Please specify a file or folder path" : "Por favor especifica un archivo o ruta de carpeta",
    "Wrong path, file/folder doesn't exist" : "La ruta es incorrecta, el correo / carpeta no existe ",
    "Could not create share" : "No fue posible crear el elemento compartido",
    "invalid permissions" : "permisos inválidos",
    "Please specify a valid user" : "Por favor especifica un usuario válido",
    "Group sharing is disabled by the administrator" : "Compartir en grupos está deshabilitado por el administrador",
    "Please specify a valid group" : "Por favor especifica un grupo válido",
    "Public link sharing is disabled by the administrator" : "Compartir ligas públicas está deshabilitado por el administrador",
    "Public upload disabled by the administrator" : "Cargas públicas deshabilitadas por el administrador",
    "Public upload is only possible for publicly shared folders" : "Las cargas públicas son posibles sólo para carpetas compartidas públicamente",
    "Invalid date, date format must be YYYY-MM-DD" : "La fecha es inválida, por favor sigue el formato AAAA-MM-DD",
    "Sharing %s failed because the back end does not allow shares from type %s" : "Se presentó  una falla al compartir %s, porque el backend no permite elementos compartidos de tipo %s",
    "You cannot share to a Circle if the app is not enabled" : "No puedes compartir al Círculo si la aplicación no está habilitada",
    "Please specify a valid circle" : "Por favor especifica un círculo válido",
    "Unknown share type" : "Tipo de elemento compartido desconocido",
    "Not a directory" : "No es una carpeta",
    "Could not lock path" : "No fue posible bloquear la ruta",
    "Wrong or no update parameter given" : "El parametro de actualización está erróneo o falta",
    "Can't change permissions for public share links" : "No es posible cambiar los permisos para ligas públicas compartidas",
    "Cannot increase permissions" : "No es posible incrementar los permisos",
    "%s is publicly shared" : "%s está compartido públicamente",
    "Share API is disabled" : "El API para compartir está deshabilitado",
    "File sharing" : "Compartir archivos",
    "This share is password-protected" : "Este elemento compartido está protegido con contraseña",
    "The password is wrong. Try again." : "La contraseña es incorrecta. Por favor inténtalo de nuevo.",
    "Password" : "Contraseña",
    "No entries found in this folder" : "No se encontraron elementos en esta carpeta",
    "Name" : "Nombre",
    "Share time" : "Tiempo de compartir",
    "Expiration date" : "Fecha de expiración",
    "Sorry, this link doesn’t seem to work anymore." : "Lo sentimos, parece que esta liga ya no funciona. ",
    "Reasons might be:" : "Las causas podrían ser:",
    "the item was removed" : "el elemento fue eliminado",
    "the link expired" : "la liga expiró",
    "sharing is disabled" : "compartir está deshabilitado",
    "For more info, please ask the person who sent this link." : "Para mayores informes, contacta a la persona que le envió esta liga.",
    "shared by %s" : "compartido por %s",
    "Add to your Nextcloud" : "Agregar a tu Nextcloud",
    "Download" : "Descargar",
    "Download %s" : "Descargar %s",
    "Direct link" : "Liga directa",
    "Upload files to %s" : "Cargar archivos a %s",
    "Select or drop files" : "Selecciona o suelta los archivos",
    "Uploading files…" : "Cargando archivos...",
    "Uploaded files:" : "Archivos cargados:"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-17.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/files_sharing/l10n/es_MX.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Shared with others" : "Compartido con otros",
    "Shared with you" : "Compartido contigo",
    "Shared by link" : "Compartido por liga",
    "Nothing shared with you yet" : "Nada ha sido compartido contigo aún",
    "Files and folders others share with you will show up here" : "Los archivos y carpetas que sean compartidos contigo se mostrarán aquí",
    "Nothing shared yet" : "Nada compartido aún",
    "Files and folders you share will show up here" : "Los archivos y carpetas que compartas se mostrarán aquí",
    "No shared links" : "No hay ligas compartidas",
    "Files and folders you share by link will show up here" : "Los archivos y carpetas que compartas por ligas se mostrarán aquí",
    "Download" : "Descargar",
    "You can upload into this folder" : "Puedes cargar archivos dentro de esta carpeta",
    "No compatible server found at {remote}" : "No se encontró un servidor compatible en {remote}",
    "Invalid server URL" : "URL del servidor inválido",
    "Failed to add the public link to your Nextcloud" : "Se presentó una falla al agregar la liga pública a tu Nextcloud",
    "No expiration date set" : "No se ha establecido la fecha de expiración",
    "Shared by" : "Compartido por",
    "File shares" : "Archivos compartidos",
    "Downloaded via public link" : "Descargado mediante una liga pública",
    "Downloaded by {email}" : "Descargado por {email}",
    "{file} downloaded via public link" : "{file} descargado mediante una liga pública",
    "{email} downloaded {file}" : "{email} descargó {file}",
    "Shared with group {group}" : "Compartido con el grupo {group}",
    "Removed share for group {group}" : "Se eliminó el elemento compartido del grupo {group}",
    "{actor} shared with group {group}" : "{actor} compartió con el grupo {group}",
    "{actor} removed share for group {group}" : "{actor} eliminó el elemento compartido del grupo {group}",
    "You shared {file} with group {group}" : "Compartiste {file} con el grupo {group}",
    "You removed group {group} from {file}" : "Eliminaste al grupo {group} de {file}",
    "{actor} shared {file} with group {group}" : "{actor} compartió {file} con el grupo {group}",
    "{actor} removed group {group} from {file}" : "{actor} eliminó el grupo {group} de {file}",
    "Shared as public link" : "Compartido como una liga pública",
    "Removed public link" : "Liga pública eliminada",
    "Public link expired" : "La liga pública ha expirado",
    "{actor} shared as public link" : "{actor} compartió como una liga pública",
    "{actor} removed public link" : "{actor} eliminó la liga pública",
    "Public link of {actor} expired" : "La liga pública de {actor} ha expirado",
    "You shared {file} as public link" : "Compartiste {file} como una liga pública",
    "You removed public link for {file}" : "Eliminaste la liga pública de {file}",
    "Public link expired for {file}" : "La liga pública para {file} ha expirado",
    "{actor} shared {file} as public link" : "{actor} ha compartido {file} como una liga pública",
    "{actor} removed public link for {file}" : "{actor} eliminó la liga pública de {file}",
    "Public link of {actor} for {file} expired" : "La liga pública de {actor} para {file} ha expirado",
    "{user} accepted the remote share" : "{user} aceptó el elemento compartido remoto",
    "{user} declined the remote share" : "{user} declinó el elemento compartido remoto",
    "You received a new remote share {file} from {user}" : "Recibiste un nuevo elemento compartido remoto {file} de {user}",
    "{user} accepted the remote share of {file}" : "{user} aceptó el elemento compartido remoto de {file}",
    "{user} declined the remote share of {file}" : "{user} declinó el elemento compartido remoto de {file}",
    "{user} unshared {file} from you" : "{user} ha dejado de compartir {file} contigo",
    "Shared with {user}" : "Compartido con {user}",
    "Removed share for {user}" : "Se eliminó el elemento compartido para {user}",
    "{actor} shared with {user}" : "{actor} compartió con {user}",
    "{actor} removed share for {user}" : "{actor} eliminó el elemento compartido para {user}",
    "Shared by {actor}" : "Compartido por {actor}",
    "{actor} removed share" : "{actor} eliminó el elemento compartido",
    "You shared {file} with {user}" : "Compartiste {file} con {user}",
    "You removed {user} from {file}" : "Eliminaste a {user} de {file}",
    "{actor} shared {file} with {user}" : "{actor} compartió {file} con {user}",
    "{actor} removed {user} from {file}" : "{actor} eliminó a {user} de {file}",
    "{actor} shared {file} with you" : "{actor} ha compartido {file} contigo",
    "A file or folder shared by mail or by public link was <strong>downloaded</strong>" : "Un archivo o carpeta comparitdo por correo o por liga pública ha sido <strong>descargado</strong>",
    "A file or folder was shared from <strong>another server</strong>" : "Un archivo o carpeta fue compartido desde <strong>otro servidor</strong>",
    "A file or folder has been <strong>shared</strong>" : "Un archivo o carpeta ha sido <strong>compartido</strong>",
    "Wrong share ID, share doesn't exist" : "ID del elemento compartido equivocado, el elemento compartido no existe",
    "Could not delete share" : "No fue posible borrar el elemento compartido",
    "Please specify a file or folder path" : "Por favor especifica un archivo o ruta de carpeta",
    "Wrong path, file/folder doesn't exist" : "La ruta es incorrecta, el correo / carpeta no existe ",
    "Could not create share" : "No fue posible crear el elemento compartido",
    "invalid permissions" : "permisos inválidos",
    "Please specify a valid user" : "Por favor especifica un usuario válido",
    "Group sharing is disabled by the administrator" : "Compartir en grupos está deshabilitado por el administrador",
    "Please specify a valid group" : "Por favor especifica un grupo válido",
    "Public link sharing is disabled by the administrator" : "Compartir ligas públicas está deshabilitado por el administrador",
    "Public upload disabled by the administrator" : "Cargas públicas deshabilitadas por el administrador",
    "Public upload is only possible for publicly shared folders" : "Las cargas públicas son posibles sólo para carpetas compartidas públicamente",
    "Invalid date, date format must be YYYY-MM-DD" : "La fecha es inválida, por favor sigue el formato AAAA-MM-DD",
    "You cannot share to a Circle if the app is not enabled" : "No puedes compartir al Círculo si la aplicación no está habilitada",
    "Please specify a valid circle" : "Por favor especifica un círculo válido",
    "Unknown share type" : "Tipo de elemento compartido desconocido",
    "Not a directory" : "No es una carpeta",
    "Could not lock path" : "No fue posible bloquear la ruta",
    "Wrong or no update parameter given" : "El parametro de actualización está erróneo o falta",
    "Can't change permissions for public share links" : "No es posible cambiar los permisos para ligas públicas compartidas",
    "shared by %s" : "compartido por %s",
    "Direct link" : "Liga directa",
    "Add to your Nextcloud" : "Agregar a tu Nextcloud",
    "Share API is disabled" : "El API para compartir está deshabilitado",
    "File sharing" : "Compartir archivos",
    "Sharing" : "Compartiendo",
    "Share" : "Compartir",
    "No entries found in this folder" : "No se encontraron elementos en esta carpeta",
    "Name" : "Nombre",
    "Share time" : "Compartido desde",
    "Expiration date" : "Fecha de expiración",
    "Sorry, this link doesn’t seem to work anymore." : "Lo sentimos, parece que esta liga ya no funciona. ",
    "Reasons might be:" : "Las causas podrían ser:",
    "the item was removed" : "el elemento fue eliminado",
    "the link expired" : "la liga expiró",
    "sharing is disabled" : "compartir está deshabilitado",
    "For more info, please ask the person who sent this link." : "Para mayores informes, contacta a la persona que le envió esta liga.",
    "Download %s" : "Descargar %s",
    "Upload files to %s" : "Cargar archivos a %s",
    "Select or drop files" : "Selecciona o suelta los archivos",
    "Uploading files…" : "Cargando archivos...",
    "Uploaded files:" : "Archivos cargados:",
    "could not delete share" : "no fue posible borrar el elemento compartido"
},
"nplurals=2; plural=(n != 1);");
